==> ViennaCL-1.6.1.tar.gz: ViennaCL-1.6.1/doc/html/search/variables_1.js <==
var searchData=
[
  ['b',['b',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a2d45022fb157b409f800b649b547c308',1,'viennacl::linalg::opencl::kernels::ambm_config::b()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a9e32e3ebd1448d8fc9c4ae20e11c1041',1,'viennacl::linalg::opencl::kernels::asbs_config::b()']]],
  ['b_5ffetching_5fpolicy',['B_fetching_policy',['../structviennacl_1_1device__specific_1_1matrix__product__parameters.html#ace1ec7dae07b9e82014e68c058c03d66',1,'viennacl::device_specific::matrix_product_parameters']]],
  ['backend',['backend',['../struct_vienna_c_l_scalar__impl.html#a67d292f8863e566d0efb1f04708264d9',1,'ViennaCLScalar_impl::backend()'],['../struct_vienna_c_l_vector__impl.html#ac9f74d13e9df7ce1332e99fca52bacc6',1,'ViennaCLVector_impl::backend()'],['../struct_vienna_c_l_matrix__impl.html#a39776c9313e28c8c2ef265c3dfcded84',1,'ViennaCLMatrix_impl::backend()']]],
  ['backend_5ftype',['backend_type',['../struct_vienna_c_l_backend__impl.html#a4ac0646f1f1f1cdc2dc7d3b0899fd5b0',1,'ViennaCLBackend_impl']]],
  ['batch_5fnum',['batch_num',['../structtest_data.html#afbeac1b8842462a94a3204945bc54535',1,'testData']]],
  ['binding_5fpolicy_5f',['binding_policy_',['../classviennacl_1_1device__specific_1_1template__base__impl.html#a12033054f52012f30bf018f6ca5291e1',1,'viennacl::device_specific::template_base_impl']]],
  ['bisect_5fkernel_5flarge',['BISECT_KERNEL_LARGE',['../namespaceviennacl_1_1linalg_1_1opencl.html#a72d6ad3f4638199544ac423cb50e558b',1,'viennacl::linalg::opencl']]],
  ['bisect_5fkernel_5flarge_5fmult_5fintervals',['BISECT_KERNEL_LARGE_MULT_INTERVALS',['../namespaceviennacl_1_1linalg_1_1opencl.html#a8342e150624fb250ba6fd27594c1528c',1,'viennacl::linalg::opencl']]],
  ['bisect_5fkernel_5flarge_5fone_5fintervals',['BISECT_KERNEL_LARGE_ONE_INTERVALS',['../namespaceviennacl_1_1linalg_1_1opencl.html#a211407186265df14562ef8a817792fd9',1,'viennacl::linalg::opencl']]],
  ['bisect_5fkernel_5fsmall',['BISECT_KERNEL_SMALL',['../namespaceviennacl_1_1linalg_1_1opencl.html#abd665da5291cf6cf9f6c4eab058df182',1,'viennacl::linalg::opencl']]],
  ['bound0',['bound0',['../structviennacl_1_1device__specific_1_1index__tuple.html#af73d1e80cf6b39591f6cb7ad28225000',1,'viennacl::device_specific::index_tuple']]],
  ['bound1',['bound1',['../structviennacl_1_1device__specific_1_1index__tuple.html#a55129a0ddf002fe6184fc2e0f1e6c428',1,'viennacl::device_specific::index_tuple']]]
];

==> ViennaCL-1.7.1.tar.gz: ViennaCL-1.7.1/doc/html/search/variables_1.js <==
var searchData=
[
  ['b',['b',['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1ambm__config.html#a2d45022fb157b409f800b649b547c308',1,'viennacl::linalg::opencl::kernels::ambm_config::b()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1asbs__config.html#a9e32e3ebd1448d8fc9c4ae20e11c1041',1,'viennacl::linalg::opencl::kernels::asbs_config::b()'],['../structviennacl_1_1linalg_1_1opencl_1_1kernels_1_1avbv__config.html#ab3678a895f8ddbaa817f76e7ac33d569',1,'viennacl::linalg::opencl::kernels::avbv_config::b()']]],
  ['b_5ffetching_5fpolicy',['B_fetching_policy',['../structviennacl_1_1device__specific_1_1matrix__product__parameters.html#ace1ec7dae07b9e82014e68c058c03d66',1,'viennacl::device_specific::matrix_product_parameters']]],
  ['backend',['backend',['../struct_vienna_c_l_scalar__impl.html#a67d292f8863e566d0efb1f04708264d9',1,'ViennaCLScalar_impl::backend()'],['../struct_vienna_c_l_vector__impl.html#ac9f74d13e9df7ce1332e99fca52bacc6',1,'ViennaCLVector_impl::backend()'],['../struct_vienna_c_l_matrix__impl.html#a39776c9313e28c8c2ef265c3dfcded84',1,'ViennaCLMatrix_impl::backend()']]],
  ['backend_5ftype',['backend_type',['../struct_vienna_c_l_backend__impl.html#a4ac0646f1f1f1cdc2dc7d3b0899fd5b0',1,'ViennaCLBackend_impl']]],
  ['batch_5fnum',['batch_num',['../structtest_data.html#afbeac1b8842462a94a3204945bc54535',1,'testData']]],
  ['bisect_5fkernel_5flarge',['BISECT_KERNEL_LARGE',['../namespaceviennacl_1_1linalg_1_1opencl.html#a72d6ad3f4638199544ac423cb50e558b',1,'viennacl::linalg::opencl']]],
  ['bisect_5fkernel_5flarge_5fmult_5fintervals',['BISECT_KERNEL_LARGE_MULT_INTERVALS',['../namespaceviennacl_1_1linalg_1_1opencl.html#a8342e150624fb250ba6fd27594c1528c',1,'viennacl::linalg::opencl']]],
  ['bisect_5fkernel_5flarge_5fone_5fintervals',['BISECT_KERNEL_LARGE_ONE_INTERVALS',['../namespaceviennacl_1_1linalg_1_1opencl.html#a211407186265df14562ef8a817792fd9',1,'viennacl::linalg::opencl']]],
  ['bisect_5fkernel_5fsmall',['BISECT_KERNEL_SMALL',['../namespaceviennacl_1_1linalg_1_1opencl.html#abd665da5291cf6cf9f6c4eab058df182',1,'viennacl::linalg::opencl']]],
  ['bound0',['bound0',['../structviennacl_1_1device__specific_1_1index__tuple.html#af73d1e80cf6b39591f6cb7ad28225000',1,'viennacl::device_specific::index_tuple']]],
  ['bound1',['bound1',['../structviennacl_1_1device__specific_1_1index__tuple.html#a55129a0ddf002fe6184fc2e0f1e6c428',1,'viennacl::device_specific::index_tuple']]]
];
